==> telegram_client-0.8.3.tar.gz: lib/telegram_client/telegram_client_telegram_bot_api_option.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!

Jika ada kendala program ini (Pastikan sebelum deal project tidak ada negosiasi harga)
Karena jika ada negosiasi harga kemungkinan

1. Software Ada yang di kurangin
2. Informasi tidak lengkap
3. Bantuan Tidak Bisa remote / full time (Ada jeda)

Sebelum program ini sampai ke pembeli developer kami sudah melakukan testing

jadi sebelum nego kami sudah melakukan berbagai konsekuensi jika nego tidak sesuai ? 
Bukan maksud kami menipu itu karena harga yang sudah di kalkulasi + bantuan tiba tiba di potong akhirnya bantuan / software kadang tidak lengkap


<!-- END LICENSE --> */
import 'package:http/http.dart';
import 'package:telegram_client/alfred/alfred.dart';

class TelegramClientTelegramBotApiOption {
  Map clientOption;
  String tokenBot;
  Alfred? alfred;
  String telegramCryptoKey;
  Uri? telegramUrlWebhook;
  Client? httpClient;
  TelegramClientTelegramBotApiOption({
    required this.tokenBot,
    required this.clientOption,
    this.alfred,
    this.telegramCryptoKey = "aeatmlvodkm9ii37l2p0WGkaAAF3BWCh",
    this.telegramUrlWebhook,
    this.httpClient,
  });
}

==> telegram_client-0.8.6.tar.gz: lib/telegram_client/telegram_client_telegram_bot_api_option.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!

Jika ada kendala program ini (Pastikan sebelum deal project tidak ada negosiasi harga)
Karena jika ada negosiasi harga kemungkinan

1. Software Ada yang di kurangin
2. Informasi tidak lengkap
3. Bantuan Tidak Bisa remote / full time (Ada jeda)

Sebelum program ini sampai ke pembeli developer kami sudah melakukan testing

jadi sebelum nego kami sudah melakukan berbagai konsekuensi jika nego tidak sesuai ? 
Bukan maksud kami menipu itu karena harga yang sudah di kalkulasi + bantuan tiba tiba di potong akhirnya bantuan / software kadang tidak lengkap


<!-- END LICENSE --> */
import 'package:http/http.dart';
import 'package:server_universe_dart/native/core/server_universe_native.dart';
import "package:server_universe_dart/native/native.dart";
// import 'package:telegram_client/serverUniverseNative/serverUniverseNative.dart';

class TelegramClientTelegramBotApiOption {
  Map clientOption;
  String tokenBot;
  ServerUniverseNative? serverUniverseNative;
  String telegramCryptoKey;
  Uri? telegramUrlWebhook;
  Client? httpClient;
  TelegramClientTelegramBotApiOption({
    required this.tokenBot,
    required this.clientOption,
    this.serverUniverseNative,
    this.telegramCryptoKey = "aeatmlvodkm9ii37l2p0WGkaAAF3BWCh",
    this.telegramUrlWebhook,
    this.httpClient,
  });
}
